@@ -26,6 +26,7 @@
 #include <stdarg.h>
 #ifndef _WIN32
 # include <time.h>
+# include <sys/time.h>
 #else
 # define WIN32_LEAN_AND_MEAN
 # include <windows.h>
@@ -87,11 +88,20 @@ _eina_counter_time_get(Eina_Nano_Time *tp)
 # elif defined(CLOCK_REALTIME)
    return clock_gettime(CLOCK_REALTIME, tp);
 # else
-   return gettimeofday(tp, NULL);
+   struct timeval tv;
+
+   if (gettimeofday(&tv, NULL))
+     return -1;
+
+   tp->tv_sec = tv.tv_sec;
+   tp->tv_nsec = tv.tv_usec * 1000L;
+
+   return 0;
 # endif
 }
 #else
-static const char EINA_ERROR_COUNTER_WINDOWS_STR[] = "Change your OS, you moron !";
+static const char EINA_ERROR_COUNTER_WINDOWS_STR[] =
+   "Change your OS, you moron !";
 static int EINA_ERROR_COUNTER_WINDOWS = 0;
 static LARGE_INTEGER _eina_counter_frequency;
 
@@ -111,28 +121,34 @@ _eina_counter_asiprintf(char *base, int *position, const char *format, ...)
    va_list ap;
 
    tmp = realloc(base, sizeof (char) * (*position + size));
-   if (!tmp) return base;
+   if (!tmp)
+      return base;
+
    result = tmp;
 
    while (1)
      {
-	va_start(ap, format);
-	n = vsnprintf(result + *position, size, format, ap);
-	va_end(ap);
+        va_start(ap, format);
+        n = vsnprintf(result + *position, size, format, ap);
+        va_end(ap);
 
-	if (n > -1 && n < size)
-	  {
-	     /* If we always have glibc > 2.2, we could just return *position += n. */
-	     *position += strlen(result + *position);
-	     return result;
-	  }
+        if (n > -1 && n < size)
+          {
+             /* If we always have glibc > 2.2, we could just return *position += n. */
+             *position += strlen(result + *position);
+             return result;
+          }
 
-	if (n > -1) size = n + 1;
-	else size <<= 1;
+        if (n > -1)
+           size = n + 1;
+        else
+           size <<= 1;
 
-	tmp = realloc(result, sizeof (char) * (*position + size));
-	if (!tmp) return result;
-	result = tmp;
+        tmp = realloc(result, sizeof (char) * (*position + size));
+        if (!tmp)
+           return result;
+
+        result = tmp;
      }
 }
 
@@ -165,12 +181,14 @@ Eina_Bool
 eina_counter_init(void)
 {
 #ifdef _WIN32
-   EINA_ERROR_COUNTER_WINDOWS = eina_error_msg_static_register(EINA_ERROR_COUNTER_WINDOWS_STR);
+   EINA_ERROR_COUNTER_WINDOWS = eina_error_msg_static_register(
+         EINA_ERROR_COUNTER_WINDOWS_STR);
    if (!QueryPerformanceFrequency(&_eina_counter_frequency))
      {
-	eina_error_set(EINA_ERROR_COUNTER_WINDOWS);
-	return EINA_FALSE;
+        eina_error_set(EINA_ERROR_COUNTER_WINDOWS);
+        return EINA_FALSE;
      }
+
 #endif /* _WIN2 */
    return EINA_TRUE;
 }
@@ -283,10 +301,11 @@ eina_counter_shutdown(void)
  * @brief Return a counter.
  *
  * @param name The name of the counter.
+ * @return A newly allocated counter.
  *
  * This function returns a new counter. It is characterized by @p
  * name. If @p name is @c NULL, the function returns @c NULL
- * immediatly. If memory allocation fails, @c NULL is returned and the
+ * immediately. If memory allocation fails, @c NULL is returned and the
  * error is set to #EINA_ERROR_OUT_OF_MEMORY.
  *
  * Whe the new counter is not needed anymore, use eina_counter_free() to
@@ -302,16 +321,16 @@ eina_counter_new(const char *name)
 
    length = strlen(name) + 1;
 
-   eina_error_set(0);
+        eina_error_set(0);
    counter = calloc(1, sizeof (Eina_Counter) + length);
    if (!counter)
      {
-	eina_error_set(EINA_ERROR_OUT_OF_MEMORY);
-	return NULL;
+        eina_error_set(EINA_ERROR_OUT_OF_MEMORY);
+        return NULL;
      }
 
-   counter->name = (char*) (counter + 1);
-   memcpy((char*) counter->name, name, length);
+   counter->name = (char *)(counter + 1);
+   memcpy((char *)counter->name, name, length);
 
    return counter;
 }
@@ -324,7 +343,7 @@ eina_counter_new(const char *name)
  * This function remove the clock of @p counter from the used clocks
  * (see eina_counter_start()) and frees the memory allocated for
  * @p counter. If @p counter is @c NULL, the function returns
- * immediatly.
+ * immediately.
  */
 EAPI void
 eina_counter_free(Eina_Counter *counter)
@@ -333,13 +352,13 @@ eina_counter_free(Eina_Counter *counter)
 
    while (counter->clocks)
      {
-	Eina_Clock *clk = (Eina_Clock *) counter->clocks;
+        Eina_Clock *clk = (Eina_Clock *)counter->clocks;
 
-	counter->clocks = eina_inlist_remove(counter->clocks, counter->clocks);
-	free(clk);
+        counter->clocks = eina_inlist_remove(counter->clocks, counter->clocks);
+        free(clk);
      }
 
-   free(counter);
+        free(counter);
 }
 
 /**
@@ -349,7 +368,7 @@ eina_counter_free(Eina_Counter *counter)
  *
  * This function specifies that the part of the code beginning just
  * after its call is being to be timed, using @p counter. If
- * @p counter is @c NULL, this function returns immediatly.
+ * @p counter is @c NULL, this function returns immediately.
  *
  * This function adds the clock associated to @p counter in a list. If
  * the memory needed by that clock can not be allocated, the function
@@ -365,14 +384,15 @@ eina_counter_start(Eina_Counter *counter)
    Eina_Nano_Time tp;
 
    EINA_SAFETY_ON_NULL_RETURN(counter);
-   if (_eina_counter_time_get(&tp) != 0) return;
+   if (_eina_counter_time_get(&tp) != 0)
+      return;
 
-   eina_error_set(0);
+        eina_error_set(0);
    clk = calloc(1, sizeof (Eina_Clock));
    if (!clk)
      {
-	eina_error_set(EINA_ERROR_OUT_OF_MEMORY);
-	return;
+        eina_error_set(EINA_ERROR_OUT_OF_MEMORY);
+        return;
      }
 
    counter->clocks = eina_inlist_prepend(counter->clocks, EINA_INLIST_GET(clk));
@@ -400,11 +420,13 @@ eina_counter_stop(Eina_Counter *counter, int specimen)
    Eina_Nano_Time tp;
 
    EINA_SAFETY_ON_NULL_RETURN(counter);
-   if (_eina_counter_time_get(&tp) != 0) return;
+   if (_eina_counter_time_get(&tp) != 0)
+      return;
 
-   clk = (Eina_Clock *) counter->clocks;
+   clk = (Eina_Clock *)counter->clocks;
 
-   if (!clk || clk->valid == EINA_TRUE) return;
+   if (!clk || clk->valid == EINA_TRUE)
+      return;
 
    clk->end = tp;
    clk->specimen = specimen;
@@ -420,7 +442,7 @@ eina_counter_stop(Eina_Counter *counter, int specimen)
  * This function returns an malloc'd string containing the dump of
  * all the valid clocks of @p counter.
  * If @p counter @c NULL, the functions exits
- * immediatly. Otherwise, the output is formattted like that:
+ * immediately. Otherwise, the output is formattted like that:
  *
  * @verbatim
  * \# specimen    experiment time    starting time    ending time
@@ -428,7 +450,7 @@ eina_counter_stop(Eina_Counter *counter, int specimen)
  * @endverbatim
  *
  * The unit of time is the nanosecond.
-*/
+ */
 EAPI char *
 eina_counter_dump(Eina_Counter *counter)
 {
@@ -438,34 +460,52 @@ eina_counter_dump(Eina_Counter *counter)
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(counter, NULL);
 
-   result = _eina_counter_asiprintf(result, &position, "# specimen\texperiment time\tstarting time\tending time\n");
-   if (!result) return NULL;
+   result = _eina_counter_asiprintf(
+         result,
+         &position,
+         "# specimen\texperiment time\tstarting time\tending time\n");
+   if (!result)
+      return NULL;
 
    EINA_INLIST_REVERSE_FOREACH(counter->clocks, clk)
-     {
-        long int start;
-        long int end;
-        long int diff;
+   {
+      long int start;
+      long int end;
+      long int diff;
 
-	if (clk->valid == EINA_FALSE) continue;
+      if (clk->valid == EINA_FALSE)
+         continue;
 
 #ifndef _WIN32
-        start = clk->start.tv_sec * 1000000000 + clk->start.tv_nsec;
-        end = clk->end.tv_sec * 1000000000 + clk->end.tv_nsec;
-        diff = (clk->end.tv_sec - clk->start.tv_sec) * 1000000000 + clk->end.tv_nsec - clk->start.tv_nsec;
+      start = clk->start.tv_sec * 1000000000 + clk->start.tv_nsec;
+      end = clk->end.tv_sec * 1000000000 + clk->end.tv_nsec;
+      diff =
+         (clk->end.tv_sec -
+          clk->start.tv_sec) * 1000000000 + clk->end.tv_nsec -
+         clk->start.tv_nsec;
 #else
-        start = (long int)(((long long int)clk->start.QuadPart * 1000000000ll) / (long long int)_eina_counter_frequency.QuadPart);
-        end = (long int)(((long long int)clk->end.QuadPart * 1000000000LL) / (long long int)_eina_counter_frequency.QuadPart);
-        diff = (long int)(((long long int)(clk->end.QuadPart - clk->start.QuadPart) * 1000000000LL) / (long long int)_eina_counter_frequency.QuadPart);
+      start =
+         (long int)(((long long int)clk->start.QuadPart *
+                     1000000000ll) /
+                    (long long int)_eina_counter_frequency.QuadPart);
+      end =
+         (long int)(((long long int)clk->end.QuadPart *
+                     1000000000LL) /
+                    (long long int)_eina_counter_frequency.QuadPart);
+      diff =
+         (long int)(((long long int)(clk->end.QuadPart -
+                                     clk->start.QuadPart) *
+                     1000000000LL) /
+                    (long long int)_eina_counter_frequency.QuadPart);
 #endif /* _WIN2 */
 
-	result = _eina_counter_asiprintf(result, &position,
-					 "%i\t%li\t%li\t%li\n",
-					 clk->specimen,
-					 diff,
-					 start,
-					 end);
-     }
+      result = _eina_counter_asiprintf(result, &position,
+                                       "%i\t%li\t%li\t%li\n",
+                                       clk->specimen,
+                                       diff,
+                                       start,
+                                       end);
+   }
 
    return result;
 }
