@@ -26,6 +26,7 @@
 #include "eina_config.h"
 #include "eina_private.h"
 #include "eina_error.h"
+#include "eina_log.h"
 
 /* undefs EINA_ARG_NONULL() so NULL checks are not compiled out! */
 #include "eina_safety_checks.h"
@@ -34,8 +35,8 @@
 /* FIXME: TODO please, refactor this :) */
 
 /*============================================================================*
- *                                  Local                                     *
- *============================================================================*/
+*                                  Local                                     *
+*============================================================================*/
 
 /**
  * @cond LOCAL
@@ -46,91 +47,98 @@ typedef struct _Eina_Accessor_Inlist Eina_Accessor_Inlist;
 
 struct _Eina_Iterator_Inlist
 {
-	Eina_Iterator iterator;
-	const Eina_Inlist *head;
-	const Eina_Inlist *current;
+   Eina_Iterator iterator;
+   const Eina_Inlist *head;
+   const Eina_Inlist *current;
 };
 
 struct _Eina_Accessor_Inlist
 {
-	Eina_Accessor accessor;
+   Eina_Accessor accessor;
 
-	const Eina_Inlist *head;
-	const Eina_Inlist *current;
+   const Eina_Inlist *head;
+   const Eina_Inlist *current;
 
-	unsigned int index;
+   unsigned int index;
 };
 
 static Eina_Bool
 eina_inlist_iterator_next(Eina_Iterator_Inlist *it, void **data) {
-	if (it->current == NULL) return EINA_FALSE;
-	if (data) *data = (void*) it->current;
+   if (!it->current)
+      return EINA_FALSE;
 
-	it->current = it->current->next;
+   if (data)
+      *data = (void *)it->current;
 
-	return EINA_TRUE;
+   it->current = it->current->next;
+
+   return EINA_TRUE;
 }
 
 static Eina_Inlist *
 eina_inlist_iterator_get_container(Eina_Iterator_Inlist *it) {
-	return (Eina_Inlist*) it->head;
+   return (Eina_Inlist *)it->head;
 }
 
 static void
 eina_inlist_iterator_free(Eina_Iterator_Inlist *it) {
-	free(it);
+   free(it);
 }
 
 static Eina_Bool
-eina_inlist_accessor_get_at(Eina_Accessor_Inlist *it, unsigned int idx, void **data) {
-	const Eina_Inlist *over;
-	unsigned int middle;
-	unsigned int i;
+eina_inlist_accessor_get_at(Eina_Accessor_Inlist *it,
+                            unsigned int idx,
+                            void **data) {
+   const Eina_Inlist *over;
+   unsigned int middle;
+   unsigned int i;
 
-	if (it->index == idx) {
-		over = it->current;
-	} else if (idx > it->index) {
-		/* Looking after current. */
-		for (i = it->index, over = it->current;
-		     i < idx && over != NULL;
-		     ++i, over = over->next)
-			;
+   if (it->index == idx)
+      over = it->current;
+   else if (idx > it->index)
+      /* Looking after current. */
+      for (i = it->index, over = it->current;
+           i < idx && over;
+           ++i, over = over->next)
+         ;
+   else
+     {
+        middle = it->index >> 1;
 
-	} else {
-		middle = it->index >> 1;
+        if (idx > middle)
+           /* Looking backward from current. */
+           for (i = it->index, over = it->current;
+                i > idx && over;
+                --i, over = over->prev)
+              ;
+        else
+           /* Looking from the start. */
+           for (i = 0, over = it->head;
+                i < idx && over;
+                ++i, over = over->next)
+              ;
+     }
 
-		if (idx > middle) {
-			/* Looking backward from current. */
-			for (i = it->index, over = it->current;
-			     i > idx && over != NULL;
-			     --i, over = over->prev)
-				;
-		} else {
-			/* Looking from the start. */
-			for (i = 0, over = it->head;
-			     i < idx && over != NULL;
-			     ++i, over = over->next)
-				;
-		}
-	}
+   if (!over)
+      return EINA_FALSE;
 
-	if (over == NULL) return EINA_FALSE;
+   it->current = over;
+   it->index = idx;
 
-	it->current = over;
-	it->index = idx;
+   if (data)
+      *data = (void *)over;
 
-	if (data) *data = (void*) over;
-	return EINA_TRUE;
+   return EINA_TRUE;
 }
 
 static Eina_Inlist *
 eina_inlist_accessor_get_container(Eina_Accessor_Inlist *it) {
-	return (Eina_Inlist *) it->head;
+   return (Eina_Inlist *)it->head;
 }
 
 static void
 eina_inlist_accessor_free(Eina_Accessor_Inlist *it) {
-	free(it);
+   free(it);
 }
 
 /**
@@ -139,12 +147,12 @@ eina_inlist_accessor_free(Eina_Accessor_Inlist *it) {
 
 
 /*============================================================================*
- *                                 Global                                     *
- *============================================================================*/
+*                                 Global                                     *
+*============================================================================*/
 
 /*============================================================================*
- *                                   API                                      *
- *============================================================================*/
+*                                   API                                      *
+*============================================================================*/
 
 /**
  * @addtogroup Eina_Inline_List_Group Inline List
@@ -152,13 +160,13 @@ eina_inlist_accessor_free(Eina_Accessor_Inlist *it) {
  * @brief These functions provide inline list management.
  *
  * Inline lists mean its nodes pointers are part of same memory as
- * data. This has the benefit of framenting memory less and avoiding
+ * data. This has the benefit of fragmenting memory less and avoiding
  * @c node->data indirection, but has the drawback of elements only
  * being able to be part of one single inlist at same time. But it is
  * possible to have inlist nodes to be part of regular lists created
  * with eina_list_append() or eina_list_prepend().
  *
- * Inline lists have its purposes, but if you don't know them go with
+ * Inline lists have their purposes, but if you don't know what those purposes are, go with
  * regular lists instead.
  *
  * @code
@@ -200,15 +208,15 @@ eina_inlist_accessor_free(Eina_Accessor_Inlist *it) {
  *    printf("list=%p\n", list);
  *    for (itr = list; itr != NULL; itr = itr->next)
  *      {
- * 	cur = EINA_INLIST_CONTAINER_GET(itr, struct my_struct);
- * 	printf("\ta=%d, b=%d\n", cur->a, cur->b);
+ *  cur = EINA_INLIST_CONTAINER_GET(itr, struct my_struct);
+ *  printf("\ta=%d, b=%d\n", cur->a, cur->b);
  *      }
  *
  *    while (list)
  *      {
- * 	Eina_Inlist *aux = list;
- * 	list = eina_inlist_remove(list, list);
- * 	free(aux);
+ *  Eina_Inlist *aux = list;
+ *  list = eina_inlist_remove(list, list);
+ *  free(aux);
  *      }
  *
  *    eina_shutdown();
@@ -221,20 +229,20 @@ eina_inlist_accessor_free(Eina_Accessor_Inlist *it) {
  */
 
 /**
- * Add a new node to end of list.
+ * Add a new node to end of a list.
  *
- * @note this code is meant to be fast, appends are O(1) and do not
- *       walk @a list anyhow.
+ * @note this code is meant to be fast: appends are O(1) and do not
+ *       walk @a list.
  *
  * @note @a new_l is considered to be in no list. If it was in another
- *       list before, please eina_inlist_remove() it before adding. No
- *       check of @a new_l prev and next pointers is done, so it' safe
+ *       list before, eina_inlist_remove() it before adding. No
+ *       check of @a new_l prev and next pointers is done, so it's safe
  *       to have them uninitialized.
  *
  * @param list existing list head or NULL to create a new list.
  * @param new_l new list node, must not be NULL.
  *
- * @return the new list head. Use it and not given @a list anymore.
+ * @return the new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist *
 eina_inlist_append(Eina_Inlist *list, Eina_Inlist *new_l)
@@ -244,16 +252,19 @@ eina_inlist_append(Eina_Inlist *list, Eina_Inlist *new_l)
    EINA_SAFETY_ON_NULL_RETURN_VAL(new_l, list);
 
    new_l->next = NULL;
-   if (!list) {
-      new_l->prev = NULL;
-      new_l->last = new_l;
-      return new_l;
-   }
+   if (!list)
+     {
+        new_l->prev = NULL;
+        new_l->last = new_l;
+        return new_l;
+     }
+
    if (list->last)
-     l = list->last;
+      l = list->last;
    else
-     for (l = list; (l) && (l->next); l = l->next)
-       ;
+      for (l = list; (l) && (l->next); l = l->next)
+         ;
+
    l->next = new_l;
    new_l->prev = l;
    list->last = new_l;
@@ -263,18 +274,18 @@ eina_inlist_append(Eina_Inlist *list, Eina_Inlist *new_l)
 /**
  * Add a new node to beginning of list.
  *
- * @note this code is meant to be fast, prepends are O(1) and do not
- *       walk @a list anyhow.
+ * @note this code is meant to be fast: appends are O(1) and do not
+ *       walk @a list.
  *
  * @note @a new_l is considered to be in no list. If it was in another
- *       list before, please eina_inlist_remove() it before adding. No
- *       check of @a new_l prev and next pointers is done, so it' safe
+ *       list before, eina_inlist_remove() it before adding. No
+ *       check of @a new_l prev and next pointers is done, so it's safe
  *       to have them uninitialized.
  *
  * @param list existing list head or NULL to create a new list.
  * @param new_l new list node, must not be NULL.
  *
- * @return the new list head. Use it and not given @a list anymore.
+ * @return the new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist *
 eina_inlist_prepend(Eina_Inlist *list, Eina_Inlist *new_l)
@@ -282,11 +293,13 @@ eina_inlist_prepend(Eina_Inlist *list, Eina_Inlist *new_l)
    EINA_SAFETY_ON_NULL_RETURN_VAL(new_l, list);
 
    new_l->prev = NULL;
-   if (!list) {
-      new_l->next = NULL;
-      new_l->last = new_l;
-      return new_l;
-   }
+   if (!list)
+     {
+        new_l->next = NULL;
+        new_l->last = new_l;
+        return new_l;
+     }
+
    new_l->next = list;
    list->prev = new_l;
    new_l->last = list->last;
@@ -297,12 +310,12 @@ eina_inlist_prepend(Eina_Inlist *list, Eina_Inlist *new_l)
 /**
  * Add a new node after the given relative item in list.
  *
- * @note this code is meant to be fast, appends are O(1) and do not
- *       walk @a list anyhow.
+ * @note this code is meant to be fast: appends are O(1) and do not
+ *       walk @a list.
  *
  * @note @a new_l is considered to be in no list. If it was in another
- *       list before, please eina_inlist_remove() it before adding. No
- *       check of @a new_l prev and next pointers is done, so it' safe
+ *       list before, eina_inlist_remove() it before adding. No
+ *       check of @a new_l prev and next pointers is done, so it's safe
  *       to have them uninitialized.
  *
  * @note @a relative is considered to be inside @a list, no checks are
@@ -314,39 +327,45 @@ eina_inlist_prepend(Eina_Inlist *list, Eina_Inlist *new_l)
  * @param new_l new list node, must not be NULL.
  * @param relative reference node, @a new_l will be added after it.
  *
- * @return the new list head. Use it and not given @a list anymore.
+ * @return the new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist *
 eina_inlist_append_relative(Eina_Inlist *list,
-			    Eina_Inlist *new_l,
-			    Eina_Inlist *relative)
+                            Eina_Inlist *new_l,
+                            Eina_Inlist *relative)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(new_l, list);
 
-   if (relative) {
-      if (relative->next) {
-	 new_l->next = relative->next;
-	 relative->next->prev = new_l;
-      } else
-	new_l->next = NULL;
-      relative->next = new_l;
-      new_l->prev = relative;
-      if (!new_l->next)
-	list->last = new_l;
-      return list;
-   }
+   if (relative)
+     {
+        if (relative->next)
+          {
+             new_l->next = relative->next;
+             relative->next->prev = new_l;
+          }
+        else
+           new_l->next = NULL;
+
+        relative->next = new_l;
+        new_l->prev = relative;
+        if (!new_l->next)
+           list->last = new_l;
+
+        return list;
+     }
+
    return eina_inlist_append(list, new_l);
 }
 
 /**
  * Add a new node before the given relative item in list.
  *
- * @note this code is meant to be fast, prepends are O(1) and do not
- *       walk @a list anyhow.
+ * @note this code is meant to be fast: appends are O(1) and do not
+ *       walk @a list.
  *
  * @note @a new_l is considered to be in no list. If it was in another
- *       list before, please eina_inlist_remove() it before adding. No
- *       check of @a new_l prev and next pointers is done, so it' safe
+ *       list before, eina_inlist_remove() it before adding. No
+ *       check of @a new_l prev and next pointers is done, so it's safe
  *       to have them uninitialized.
  *
  * @note @a relative is considered to be inside @a list, no checks are
@@ -358,52 +377,57 @@ eina_inlist_append_relative(Eina_Inlist *list,
  * @param new_l new list node, must not be NULL.
  * @param relative reference node, @a new_l will be added before it.
  *
- * @return the new list head. Use it and not given @a list anymore.
+ * @return the new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist *
 eina_inlist_prepend_relative(Eina_Inlist *list,
-			     Eina_Inlist *new_l,
-			     Eina_Inlist *relative)
+                             Eina_Inlist *new_l,
+                             Eina_Inlist *relative)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(new_l, list);
 
-   if (relative) {
-      new_l->prev = relative->prev;
-      new_l->next = relative;
-      relative->prev = new_l;
-      if (new_l->prev) {
-	 new_l->prev->next = new_l;
-	 /* new_l->next could not be NULL, as it was set to 'relative' */
-	 assert(new_l->next);
-	 return list;
-      } else {
-	 /* new_l->next could not be NULL, as it was set to 'relative' */
-	 assert(new_l->next);
+   if (relative)
+     {
+        new_l->prev = relative->prev;
+        new_l->next = relative;
+        relative->prev = new_l;
+        if (new_l->prev)
+          {
+             new_l->prev->next = new_l;
+             /* new_l->next could not be NULL, as it was set to 'relative' */
+             assert(new_l->next);
+             return list;
+          }
+        else
+          {
+             /* new_l->next could not be NULL, as it was set to 'relative' */
+             assert(new_l->next);
+
+             new_l->last = list->last;
+             list->last = NULL;
+             return new_l;
+          }
+     }
 
-	 new_l->last = list->last;
-	 list->last = NULL;
-	 return new_l;
-      }
-   }
    return eina_inlist_prepend(list, new_l);
 }
 
 /**
  * Remove node from list.
  *
- * @note this code is meant to be fast, removals are O(1) and do not
- *       walk @a list anyhow.
+ * @note this code is meant to be fast: appends are O(1) and do not
+ *       walk @a list.
  *
  * @note @a item is considered to be inside @a list, no checks are
  *       done to confirm that and giving nodes from different lists
- *       will lead to problems, specially if @a item is the head since
+ *       will lead to problems, especially if @a item is the head since
  *       it will be different from @a list and the wrong new head will
  *       be returned.
  *
  * @param list existing list head, must not be NULL.
  * @param item existing list node, must not be NULL.
  *
- * @return the new list head. Use it and not given @a list anymore.
+ * @return the new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist *
 eina_inlist_remove(Eina_Inlist *list, Eina_Inlist *item)
@@ -413,22 +437,31 @@ eina_inlist_remove(Eina_Inlist *list, Eina_Inlist *item)
    /* checkme */
    EINA_SAFETY_ON_NULL_RETURN_VAL(list, NULL);
    EINA_SAFETY_ON_NULL_RETURN_VAL(item, list);
-   EINA_SAFETY_ON_TRUE_RETURN_VAL
-     ((item != list) && (item->prev == NULL) && (item->next == NULL), list);
+   if (EINA_UNLIKELY((item != list) && (!item->prev) && (!item->next)))
+     {
+        eina_error_set(EINA_ERROR_SAFETY_FAILED);
+        EINA_LOG_ERR("safety check failed: item %p does not appear to be part of an inlist!", item);
+        return list;
+     }
 
    if (item->next)
-     item->next->prev = item->prev;
+      item->next->prev = item->prev;
+
+   if (item->prev)
+     {
+        item->prev->next = item->next;
+        return_l = list;
+     }
+   else
+     {
+        return_l = item->next;
+        if (return_l)
+           return_l->last = list->last;
+     }
 
-   if (item->prev) {
-      item->prev->next = item->next;
-      return_l = list;
-   } else {
-      return_l = item->next;
-      if (return_l)
-	return_l->last = list->last;
-   }
    if (item == list->last)
-     list->last = item->prev;
+      list->last = item->prev;
+
    item->next = NULL;
    item->prev = NULL;
    return return_l;
@@ -437,17 +470,17 @@ eina_inlist_remove(Eina_Inlist *list, Eina_Inlist *item)
 /**
  * Move existing node to beginning of list.
  *
- * @note this code is meant to be fast, promotion is O(1) and do not
- *       walk @a list anyhow.
+ * @note this code is meant to be fast: appends are O(1) and do not
+ *       walk @a list.
  *
- * @note @a item is considered to be inside @a list, no checks are
- *       done to confirm that and giving nodes from different lists
+ * @note @a item is considered to be inside @a list. No checks are
+ *       done to confirm this, and giving nodes from different lists
  *       will lead to problems.
  *
  * @param list existing list head or NULL to create a new list.
  * @param item list node to move to beginning (head), must not be NULL.
  *
- * @return the new list head. Use it and not given @a list anymore.
+ * @return the new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist *
 eina_inlist_promote(Eina_Inlist *list, Eina_Inlist *item)
@@ -455,14 +488,16 @@ eina_inlist_promote(Eina_Inlist *list, Eina_Inlist *item)
    EINA_SAFETY_ON_NULL_RETURN_VAL(list, NULL);
    EINA_SAFETY_ON_NULL_RETURN_VAL(item, list);
 
-   if (item == list) return list;
+   if (item == list)
+      return list;
 
    if (item->next)
-     item->next->prev = item->prev;
+      item->next->prev = item->prev;
+
    item->prev->next = item->next;
 
    if (list->last == item)
-     list->last = item->prev;
+      list->last = item->prev;
 
    item->next = list;
    item->prev = NULL;
@@ -477,17 +512,17 @@ eina_inlist_promote(Eina_Inlist *list, Eina_Inlist *item)
 /**
  * Move existing node to end of list.
  *
- * @note this code is meant to be fast, demoting is O(1) and do not
- *       walk @a list anyhow.
+ * @note this code is meant to be fast: appends are O(1) and do not
+ *       walk @a list.
  *
- * @note @a item is considered to be inside @a list, no checks are
- *       done to confirm that and giving nodes from different lists
+ * @note @a item is considered to be inside @a list. No checks are
+ *       done to confirm this, and giving nodes from different lists
  *       will lead to problems.
  *
  * @param list existing list head or NULL to create a new list.
  * @param item list node to move to end (tail), must not be NULL.
  *
- * @return the new list head. Use it and not given @a list anymore.
+ * @return the new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist *
 eina_inlist_demote(Eina_Inlist *list, Eina_Inlist *item)
@@ -497,20 +532,22 @@ eina_inlist_demote(Eina_Inlist *list, Eina_Inlist *item)
    EINA_SAFETY_ON_NULL_RETURN_VAL(list, NULL);
    EINA_SAFETY_ON_NULL_RETURN_VAL(item, list);
 
-   if (list->last == item) return list;
+   if (list->last == item)
+      return list;
 
    if (!list->last)
      {
-	for (l = list; l->next; l = l->next)
-	  ;
-	list->last = l;
+        for (l = list; l->next; l = l->next)
+           ;
+        list->last = l;
      }
 
    l = list;
    if (item->prev)
-     item->prev->next = item->next;
+      item->prev->next = item->next;
    else
-     l = item->next;
+      l = item->next;
+
    item->next->prev = item->prev;
 
    list->last->next = item;
@@ -524,7 +561,7 @@ eina_inlist_demote(Eina_Inlist *list, Eina_Inlist *item)
 /**
  * Find given node in list, returns itself if found, NULL if not.
  *
- * @warning this is an expensive call and have O(n) cost, possibly
+ * @warning this is an expensive call and has O(n) cost, possibly
  *    walking the whole list.
  *
  * @param list existing list to search @a item in, must not be NULL.
@@ -538,9 +575,9 @@ eina_inlist_find(Eina_Inlist *list, Eina_Inlist *item)
    Eina_Inlist *l;
 
    for (l = list; l; l = l->next) {
-      if (l == item)
-	return item;
-   }
+        if (l == item)
+           return item;
+     }
    return NULL;
 }
 
@@ -554,7 +591,7 @@ eina_inlist_find(Eina_Inlist *list, Eina_Inlist *item)
  * list is @c NULL, 0 is returned.
  *
  * @warning This is an order-N operation and so the time will depend
- *    on the number of elements on the list, that is, it might become
+ *    on the number of elements on the list, so, it might become
  *    slow for big lists!
  */
 EAPI unsigned int
@@ -564,13 +601,13 @@ eina_inlist_count(const Eina_Inlist *list)
    unsigned int i = 0;
 
    for (l = list; l; l = l->next)
-     i++;
+      i++;
 
    return i;
 }
 
 /**
- * @brief Returned a new iterator asociated to a list.
+ * @brief Returns a new iterator associated to @a list.
  *
  * @param list The list.
  * @return A new iterator.
@@ -586,8 +623,8 @@ eina_inlist_count(const Eina_Inlist *list)
  * returned.
  *
  * @warning if the list structure changes then the iterator becomes
- *    invalid! That is, if you add or remove nodes this iterator
- *    behavior is undefined and your program may crash!
+ *    invalid, and if you add or remove nodes iterator
+ *    behavior is undefined, and your program may crash!
  */
 EAPI Eina_Iterator *
 eina_inlist_iterator_new(const Eina_Inlist *list)
@@ -596,16 +633,19 @@ eina_inlist_iterator_new(const Eina_Inlist *list)
 
    eina_error_set(0);
    it = calloc(1, sizeof (Eina_Iterator_Inlist));
-   if (!it) {
-      eina_error_set(EINA_ERROR_OUT_OF_MEMORY);
-      return NULL;
-   }
+   if (!it)
+     {
+        eina_error_set(EINA_ERROR_OUT_OF_MEMORY);
+        return NULL;
+     }
 
    it->head = list;
    it->current = list;
 
+   it->iterator.version = EINA_ITERATOR_VERSION;
    it->iterator.next = FUNC_ITERATOR_NEXT(eina_inlist_iterator_next);
-   it->iterator.get_container = FUNC_ITERATOR_GET_CONTAINER(eina_inlist_iterator_get_container);
+   it->iterator.get_container = FUNC_ITERATOR_GET_CONTAINER(
+         eina_inlist_iterator_get_container);
    it->iterator.free = FUNC_ITERATOR_FREE(eina_inlist_iterator_free);
 
    EINA_MAGIC_SET(&it->iterator, EINA_MAGIC_ITERATOR);
@@ -614,7 +654,7 @@ eina_inlist_iterator_new(const Eina_Inlist *list)
 }
 
 /**
- * @brief Returned a new accessor asociated to a list.
+ * @brief Returns a new accessor associated to a list.
  *
  * @param list The list.
  * @return A new accessor.
@@ -628,26 +668,29 @@ eina_inlist_iterator_new(const Eina_Inlist *list)
 EAPI Eina_Accessor *
 eina_inlist_accessor_new(const Eina_Inlist *list)
 {
-   Eina_Accessor_Inlist *it;
+   Eina_Accessor_Inlist *ac;
 
-   eina_error_set(0);
-   it = calloc(1, sizeof (Eina_Accessor_Inlist));
-   if (!it) {
-      eina_error_set(EINA_ERROR_OUT_OF_MEMORY);
-      return NULL;
-   }
+        eina_error_set(0);
+   ac = calloc(1, sizeof (Eina_Accessor_Inlist));
+   if (!ac)
+     {
+        eina_error_set(EINA_ERROR_OUT_OF_MEMORY);
+        return NULL;
+     }
 
-   it->head = list;
-   it->current = list;
-   it->index = 0;
+   ac->head = list;
+   ac->current = list;
+   ac->index = 0;
 
-   it->accessor.get_at = FUNC_ACCESSOR_GET_AT(eina_inlist_accessor_get_at);
-   it->accessor.get_container = FUNC_ACCESSOR_GET_CONTAINER(eina_inlist_accessor_get_container);
-   it->accessor.free = FUNC_ACCESSOR_FREE(eina_inlist_accessor_free);
+   ac->accessor.version = EINA_ACCESSOR_VERSION;
+   ac->accessor.get_at = FUNC_ACCESSOR_GET_AT(eina_inlist_accessor_get_at);
+   ac->accessor.get_container = FUNC_ACCESSOR_GET_CONTAINER(
+         eina_inlist_accessor_get_container);
+   ac->accessor.free = FUNC_ACCESSOR_FREE(eina_inlist_accessor_free);
 
-   EINA_MAGIC_SET(&it->accessor, EINA_MAGIC_ACCESSOR);
+   EINA_MAGIC_SET(&ac->accessor, EINA_MAGIC_ACCESSOR);
 
-   return &it->accessor;
+   return &ac->accessor;
 }
 
 /**
