@@ -39,15 +39,15 @@ _eina_mempool_bench(Eina_Mempool *mp, int request)
 
    for (i = 0; i < 100; ++i)
      {
-	for (j = 0; j < request; ++j)
-	  {
-	     eina_array_push(array, eina_mempool_malloc(mp, sizeof (int)));
-	  }
+        for (j = 0; j < request; ++j)
+          {
+             eina_array_push(array, eina_mempool_malloc(mp, sizeof (int)));
+          }
 
-	for (j = 0; j < request; ++j)
-	  {
-	     eina_mempool_free(mp, eina_array_pop(array));
-	  }
+        for (j = 0; j < request; ++j)
+          {
+             eina_mempool_free(mp, eina_array_pop(array));
+          }
      }
 
    eina_array_free(array);
@@ -108,7 +108,15 @@ eina_mempool_ememoa_unknown(int request)
 {
    Eina_Mempool *mp;
 
-   mp = eina_mempool_add("ememoa_unknown", "test", NULL, 0, 2, sizeof (int), 8, sizeof (int) * 2, 8);
+   mp = eina_mempool_add("ememoa_unknown",
+                         "test",
+                         NULL,
+                         0,
+                         2,
+                         sizeof (int),
+                         8,
+                         sizeof (int) * 2,
+                         8);
    _eina_mempool_bench(mp, request);
    eina_mempool_del(mp);
 }
@@ -127,15 +135,15 @@ eina_mempool_glib(int request)
 
    for (i = 0; i < 100; ++i)
      {
-	for (j = 0; j < request; ++j)
-	  {
-	     eina_array_push(array, g_slice_alloc(sizeof (int)));
-	  }
+        for (j = 0; j < request; ++j)
+          {
+             eina_array_push(array, g_slice_alloc(sizeof (int)));
+          }
 
-	for (j = 0; j < request; ++j)
-	  {
-	     g_slice_free1(sizeof (int), eina_array_pop(array));
-	  }
+        for (j = 0; j < request; ++j)
+          {
+             g_slice_free1(sizeof (int), eina_array_pop(array));
+          }
      }
 
    eina_array_free(array);
@@ -148,21 +156,33 @@ void
 eina_bench_mempool(Eina_Benchmark *bench)
 {
 #ifdef EINA_BUILD_CHAINED_POOL
-   eina_benchmark_register(bench, "chained mempool", EINA_BENCHMARK(eina_mempool_chained_mempool), 10, 1000, 10);
+   eina_benchmark_register(bench, "chained mempool",
+                           EINA_BENCHMARK(
+                              eina_mempool_chained_mempool), 10, 1000, 10);
 #endif
 #ifdef EINA_BUILD_PASS_THROUGH
-   eina_benchmark_register(bench, "pass through", EINA_BENCHMARK(eina_mempool_pass_through), 10, 1000, 10);
+   eina_benchmark_register(bench, "pass through",
+                           EINA_BENCHMARK(
+                              eina_mempool_pass_through),    10, 1000, 10);
 #endif
 #ifdef EINA_BUILD_FIXED_BITMAP
-   eina_benchmark_register(bench, "fixed bitmap", EINA_BENCHMARK(eina_mempool_fixed_bitmap), 10, 1000, 10);
+   eina_benchmark_register(bench, "fixed bitmap",
+                           EINA_BENCHMARK(
+                              eina_mempool_fixed_bitmap),    10, 1000, 10);
 #endif
 #ifdef EINA_BUILD_EMEMOA_FIXED
-   eina_benchmark_register(bench, "ememoa fixed", EINA_BENCHMARK(eina_mempool_ememoa_fixed), 10, 1000, 10);
+   eina_benchmark_register(bench, "ememoa fixed",
+                           EINA_BENCHMARK(
+                              eina_mempool_ememoa_fixed),    10, 1000, 10);
 #endif
 #ifdef EINA_BUILD_EMEMOA_UNKNOWN
-   eina_benchmark_register(bench, "ememoa unknown", EINA_BENCHMARK(eina_mempool_ememoa_unknown), 10, 1000, 10);
+   eina_benchmark_register(bench, "ememoa unknown",
+                           EINA_BENCHMARK(
+                              eina_mempool_ememoa_unknown),  10, 1000, 10);
 #endif
 #ifdef EINA_BENCH_HAVE_GLIB
-   eina_benchmark_register(bench, "gslice", EINA_BENCHMARK(eina_mempool_glib), 10, 1000, 10);
+   eina_benchmark_register(bench, "gslice",
+                           EINA_BENCHMARK(
+                              eina_mempool_glib),            10, 1000, 10);
 #endif
 }
